@@ -1,5 +1,5 @@
 import os
-from enum import Enum
+# from enum import Enum
 from pathlib import Path
 
 from samesyslib.utils import load_config
@@ -9,10 +9,10 @@ DEFAULT_ENV = "dev"
 CONFIG_PATH = os.getenv("CONFIG_PATH", None)
 
 
-class Envs(Enum):
-    DEV = "dev"
-    STG = "stg"
-    PROD = "prod"
+# class Envs(Enum):
+#     DEV = "dev"
+#     STG = "stg"
+#     PROD = "prod"
 
 
 class DBParams(object):
@@ -31,6 +31,7 @@ class DBParams(object):
 class DBConfig(object):
     def __init__(self, env=None, schema=None, bi=False, connect_args={}):
         self._schema = schema
+        self._env = env
         self._bi = bi
         self._connect_args = connect_args
 
@@ -41,15 +42,14 @@ class DBConfig(object):
         self._proceed()
 
     def _change_env(self, env):
-        if env and env not in Envs._value2member_map_:
-            raise Exception(f"ERROR: passed env: {env} is not valid")
+        # if env and env not in Envs._value2member_map_:
+        #     raise Exception(f"ERROR: passed env: {env} is not valid")
         self._env = env or DEFAULT_ENV
 
     def _load_from_config(self):
         path = Path.home() / Path(CONFIG_PATH)
         cred = load_config(path)
         conf = cred[self._env]
-        conf["schema"] = "daily"
         self.db_connection = DBParams(**conf)
 
         conf = cred[self._env]
